@@ -39,6 +39,7 @@
 
 """
 import json
+import os
 
 from deprecated.sphinx import deprecated
 
@@ -204,7 +205,7 @@ class Track(core.Track):
             metadata,
         )
 
-        self.path = self.get_path("data")
+        self.path = os.path.normpath(self.get_path("data"))
         self.genre = [genre for genre in self.track_id.split("#")[4:] if genre != ""]
         self.mbid = self.track_id.split("#")[2]
         self.mbid_group = self.track_id.split("#")[3]
@@ -363,7 +364,7 @@ class Track(core.Track):
 
     @core.cached_property
     def acousticbrainz_metadata(self):
-        return load_extractor(self.path)
+        return load_extractor(os.path.normpath(self.path))
 
     def to_jams(self):
         """the track's data in jams format
@@ -374,7 +375,7 @@ class Track(core.Track):
         """
         return jams_utils.jams_converter(
             metadata={
-                "features": load_extractor(self.path),
+                "features": load_extractor(os.path.normpath(self.path)),
                 "duration": self.acousticbrainz_metadata["metadata"][
                     "audio_properties"
                 ]["length"],
