@@ -9,14 +9,14 @@
 """
 
 import csv
-import logging
 import os
-import shutil
 import re
 from typing import BinaryIO, TextIO, Optional, Tuple, Dict, List
 
+from deprecated.sphinx import deprecated
 import librosa
 import numpy as np
+from smart_open import open
 
 from mirdata import download_utils
 from mirdata import jams_utils
@@ -40,6 +40,12 @@ booktitle={Proceedings of the 12th International Society for Music Information R
 }
 """
 
+INDEXES = {
+    "default": "2.0",
+    "test": "2.0",
+    "2.0": core.Index(filename="billboard_index_2.0.json"),
+}
+
 REMOTES = {
     "metadata": download_utils.RemoteFileMetadata(
         filename="billboard-2.0-index.csv",
@@ -286,12 +292,14 @@ def load_chords(fhandle: TextIO):
 
     reader = csv.reader(fhandle, delimiter="\t")
     for l in reader:
-        if len(l):
+        if len(l) > 0:
             start_times.append(float(l[0]))
             end_times.append(float(l[1]))
             chords.append(l[2])
 
-    chord_data = annotations.ChordData(np.array([start_times, end_times]).T, chords)
+    chord_data = annotations.ChordData(
+        np.array([start_times, end_times]).T, "s", chords, "jams"
+    )
     return chord_data
 
 
@@ -299,7 +307,7 @@ def load_sections(fpath: str):
     """Load letter-annotated sections from a Salami LAB file.
 
     Args:
-        fpath (str): path to audio file
+        fpath (str): path to sections file
 
     Returns:
         SectionData: section data
@@ -312,7 +320,7 @@ def load_named_sections(fpath: str):
     """Load name-annotated sections from a Salami LAB file.
 
     Args:
-        fpath (str): path to audio file
+        fpath (str): path to sections file
 
     Returns:
         SectionData: section data
@@ -351,7 +359,7 @@ def _load_sections(fpath: str, section_type: str):
             sections.append(timed_sections_clean[idx]["section"][section_label_idx])
 
     section_data = annotations.SectionData(
-        np.array([start_times, end_times]).T, sections
+        np.array([start_times, end_times]).T, "s", sections, "open"
     )
     return section_data
 
@@ -471,12 +479,14 @@ class Dataset(core.Dataset):
     The McGill Billboard dataset
     """
 
-    def __init__(self, data_home=None):
+    def __init__(self, data_home=None, version="default"):
         super().__init__(
             data_home,
+            version,
             name="billboard",
             track_class=Track,
             bibtex=BIBTEX,
+            indexes=INDEXES,
             remotes=REMOTES,
             license_info=LICENSE_INFO,
         )
@@ -485,17 +495,14 @@ class Dataset(core.Dataset):
     def _metadata(self):
         metadata_path = os.path.join(self.data_home, "billboard-2.0-index.csv")
 
-        if not os.path.exists(metadata_path):
+        try:
+            with open(metadata_path, "r") as fhandle:
+                reader = csv.reader(fhandle, delimiter=",")
+                next(reader, None)
+                raw_data = [line for line in reader if line != []]
+        except FileNotFoundError:
             raise FileNotFoundError("Metadata not found. Did you run .download()?")
 
-        with open(metadata_path, "r") as fhandle:
-            reader = csv.reader(fhandle, delimiter=",")
-            next(reader, None)
-            raw_data = []
-            for line in reader:
-                if line != []:
-                    raw_data.append(line)
-
         metadata_index = {}
         for line in raw_data:
             track_id = line[0]
@@ -510,18 +517,30 @@ class Dataset(core.Dataset):
             }
         return metadata_index
 
-    @core.copy_docs(load_audio)
+    @deprecated(
+        reason="Use mirdata.datasets.billboard.load_audio",
+        version="0.3.4",
+    )
     def load_audio(self, *args, **kwargs):
         return load_audio(*args, **kwargs)
 
-    @core.copy_docs(load_sections)
+    @deprecated(
+        reason="Use mirdata.datasets.billboard.load_sections",
+        version="0.3.4",
+    )
     def load_sections(self, *args, **kwargs):
         return load_sections(*args, **kwargs)
 
-    @core.copy_docs(load_named_sections)
+    @deprecated(
+        reason="Use mirdata.datasets.billboard.load_named_sections",
+        version="0.3.4",
+    )
     def load_named_sections(self, *args, **kwargs):
         return load_named_sections(*args, **kwargs)
 
-    @core.copy_docs(load_chords)
+    @deprecated(
+        reason="Use mirdata.datasets.billboard.load_chords",
+        version="0.3.4",
+    )
     def load_chords(self, *args, **kwargs):
         return load_chords(*args, **kwargs)
