@@ -33,6 +33,7 @@ import csv
 import os
 from typing import Tuple, TextIO, Optional, BinaryIO
 
+from deprecated.sphinx import deprecated
 import librosa
 import numpy as np
 
@@ -49,6 +50,13 @@ BIBTEX = """@inproceedings{mauch2009beatles,
 LICENSE_INFO = (
     "Unfortunately we couldn't find the license information for Queen dataset."
 )
+
+INDEXES = {
+    "default": "1.0",
+    "test": "1.0",
+    "1.0": core.Index(filename="queen_index_1.0.json"),
+}
+
 REMOTES = {
     "annotations": download_utils.RemoteFileMetadata(
         filename="Queen Annotations.tar.gz",
@@ -185,7 +193,9 @@ def load_chords(fhandle: TextIO) -> annotations.ChordData:
         end_times.append(float(line[1]))
         chords.append(line[2])
 
-    return annotations.ChordData(np.array([start_times, end_times]).T, chords)
+    return annotations.ChordData(
+        np.array([start_times, end_times]).T, "s", chords, "harte"
+    )
 
 
 @io.coerce_to_string_io
@@ -207,7 +217,9 @@ def load_key(fhandle: TextIO) -> annotations.KeyData:
             end_times.append(float(line[1]))
             keys.append(line[3])
 
-    return annotations.KeyData(np.array([start_times, end_times]).T, keys)
+    return annotations.KeyData(
+        np.array([start_times, end_times]).T, "s", keys, "key_mode"
+    )
 
 
 @io.coerce_to_string_io
@@ -228,7 +240,9 @@ def load_sections(fhandle: TextIO) -> annotations.SectionData:
         end_times.append(float(line[1]))
         sections.append(line[3])
 
-    return annotations.SectionData(np.array([start_times, end_times]).T, sections)
+    return annotations.SectionData(
+        np.array([start_times, end_times]).T, "s", sections, "open"
+    )
 
 
 @core.docstring_inherit(core.Dataset)
@@ -237,29 +251,43 @@ class Dataset(core.Dataset):
     Queen dataset
     """
 
-    def __init__(self, data_home=None):
+    def __init__(self, data_home=None, version="default"):
         super().__init__(
             data_home,
+            version,
             name="queen",
             track_class=Track,
             bibtex=BIBTEX,
+            indexes=INDEXES,
             remotes=REMOTES,
             download_info=DOWNLOAD_INFO,
             license_info=LICENSE_INFO,
         )
 
-    @core.copy_docs(load_audio)
+    @deprecated(
+        reason="Use mirdata.datasets.queen.load_audio",
+        version="0.3.4",
+    )
     def load_audio(self, *args, **kwargs):
         return load_audio(*args, **kwargs)
 
-    @core.copy_docs(load_key)
+    @deprecated(
+        reason="Use mirdata.datasets.queen.load_key",
+        version="0.3.4",
+    )
     def load_key(self, *args, **kwargs):
         return load_key(*args, **kwargs)
 
-    @core.copy_docs(load_chords)
+    @deprecated(
+        reason="Use mirdata.datasets.queen.load_chords",
+        version="0.3.4",
+    )
     def load_chords(self, *args, **kwargs):
         return load_chords(*args, **kwargs)
 
-    @core.copy_docs(load_sections)
+    @deprecated(
+        reason="Use mirdata.datasets.queen.load_sections",
+        version="0.3.4",
+    )
     def load_sections(self, *args, **kwargs):
         return load_sections(*args, **kwargs)
