@@ -2,10 +2,13 @@ import numpy as np
 from mirdata import annotations
 from mirdata.datasets import compmusic_jingju_acappella
 from tests.test_utils import run_track_tests
+import os
 
 
 def test_track():
-    data_home = "tests/resources/mir_datasets/compmusic_jingju_acappella"
+    data_home = os.path.normpath(
+        "tests/resources/mir_datasets/compmusic_jingju_acappella"
+    )
     track_id = "lseh-Tan_Yang_jia-Hong_yang_dong-qm"
 
     dataset = compmusic_jingju_acappella.Dataset(data_home)
@@ -13,19 +16,43 @@ def test_track():
 
     expected_attributes = {
         "track_id": "lseh-Tan_Yang_jia-Hong_yang_dong-qm",
-        "audio_path": "tests/resources/mir_datasets/compmusic_jingju_acappella/"
-        + "wav/laosheng/lseh-Tan_Yang_jia-Hong_yang_dong-qm.wav",
-        "phrase_path": "tests/resources/mir_datasets/compmusic_jingju_acappella/"
-        + "annotation_txt/laosheng/lseh-Tan_Yang_jia-Hong_yang_dong-qm_phrase.txt",
-        "phrase_char_path": "tests/resources/mir_datasets/compmusic_jingju_acappella/"
-        + "annotation_txt/laosheng/lseh-Tan_Yang_jia-Hong_yang_dong-qm_phrase_char.txt",
-        "phoneme_path": "tests/resources/mir_datasets/compmusic_jingju_acappella/"
-        + "annotation_txt/laosheng/lseh-Tan_Yang_jia-Hong_yang_dong-qm_phoneme.txt",
-        "syllable_path": "tests/resources/mir_datasets/compmusic_jingju_acappella/"
-        + "annotation_txt/laosheng/lseh-Tan_Yang_jia-Hong_yang_dong-qm_syllable.txt",
+        "audio_path": os.path.join(
+            os.path.normpath(
+                "tests/resources/mir_datasets/compmusic_jingju_acappella/"
+            ),
+            "wav/laosheng/lseh-Tan_Yang_jia-Hong_yang_dong-qm.wav",
+        ),
+        "phrase_path": os.path.join(
+            os.path.normpath(
+                "tests/resources/mir_datasets/compmusic_jingju_acappella/"
+            ),
+            "annotation_txt/laosheng/lseh-Tan_Yang_jia-Hong_yang_dong-qm_phrase.txt",
+        ),
+        "phrase_char_path": os.path.join(
+            os.path.normpath(
+                "tests/resources/mir_datasets/compmusic_jingju_acappella/"
+            ),
+            "annotation_txt/laosheng/lseh-Tan_Yang_jia-Hong_yang_dong-qm_phrase_char.txt",
+        ),
+        "phoneme_path": os.path.join(
+            os.path.normpath(
+                "tests/resources/mir_datasets/compmusic_jingju_acappella/"
+            ),
+            "annotation_txt/laosheng/lseh-Tan_Yang_jia-Hong_yang_dong-qm_phoneme.txt",
+        ),
+        "syllable_path": os.path.join(
+            os.path.normpath(
+                "tests/resources/mir_datasets/compmusic_jingju_acappella/"
+            ),
+            "annotation_txt/laosheng/lseh-Tan_Yang_jia-Hong_yang_dong-qm_syllable.txt",
+        ),
         "title": "Türk Müziğinde 75 Büyük Bestekar/ 75 Great Composers In Turkish Classical Music",
-        "textgrid_path": "tests/resources/mir_datasets/compmusic_jingju_acappella/"
-        + "textgrid/laosheng/lseh-Tan_Yang_jia-Hong_yang_dong-qm.TextGrid",
+        "textgrid_path": os.path.join(
+            os.path.normpath(
+                "tests/resources/mir_datasets/compmusic_jingju_acappella/"
+            ),
+            "textgrid/laosheng/lseh-Tan_Yang_jia-Hong_yang_dong-qm.TextGrid",
+        ),
         "work": "“叹杨家投宋主心血用尽”——《洪羊洞》（杨延昭）",
         "details": None,
     }
@@ -34,8 +61,8 @@ def test_track():
         "audio": tuple,
         "phrase": annotations.LyricData,
         "phrase_char": annotations.LyricData,
-        "phoneme": annotations.EventData,
-        "syllable": annotations.EventData,
+        "phoneme": annotations.LyricData,
+        "syllable": annotations.LyricData,
         "work": str,
         "details": None.__class__,
     }
@@ -90,8 +117,7 @@ def test_to_jams():
         None,
     ]
 
-    # Events
-    phonemes = jam.search(namespace="tag_open")[0]["data"]
+    phonemes = jam.search(namespace="lyrics")[2]["data"]
     assert len(phonemes) == 6
     assert [phoneme.time for phoneme in phonemes] == [0.0, 1.06, 1.16, 2.53, 2.65, 2.94]
     assert [phoneme.duration for phoneme in phonemes] == [
@@ -128,7 +154,6 @@ def test_load_phrases():
     assert type(parsed_phrases) == annotations.LyricData
     assert type(parsed_phrases.intervals) is np.ndarray
     assert type(parsed_phrases.lyrics) is list
-    assert type(parsed_phrases.pronunciations) is None.__class__
 
     # Check values
     assert np.array_equal(
@@ -175,7 +200,6 @@ def test_load_phrases():
     assert type(parsed_phrases_char) == annotations.LyricData
     assert type(parsed_phrases_char.intervals) is np.ndarray
     assert type(parsed_phrases_char.lyrics) is list
-    assert type(parsed_phrases_char.pronunciations) is None.__class__
 
     # Check values
     assert np.array_equal(
@@ -231,9 +255,9 @@ def test_load_phoneme():
     parsed_phonemes = compmusic_jingju_acappella.load_phonemes(phoneme_path)
 
     # Check types
-    assert type(parsed_phonemes) == annotations.EventData
+    assert type(parsed_phonemes) == annotations.LyricData
     assert type(parsed_phonemes.intervals) is np.ndarray
-    assert type(parsed_phonemes.events) is list
+    assert type(parsed_phonemes.lyrics) is list
 
     # Check values
     assert np.array_equal(
@@ -244,7 +268,7 @@ def test_load_phoneme():
         parsed_phonemes.intervals[:, 1],
         np.array([1.06, 1.16, 2.53, 2.65, 2.94, 3.05]),
     )
-    assert parsed_phonemes.events == ["", "@", "r\\'", "?", "AU^", "9"]
+    assert parsed_phonemes.lyrics == ["", "@", "r\\'", "?", "AU^", "9"]
 
     assert compmusic_jingju_acappella.load_phonemes(None) is None
 
@@ -259,9 +283,9 @@ def test_load_syllable():
     parsed_syllable = compmusic_jingju_acappella.load_syllable(syllable_path)
 
     # Check types
-    assert type(parsed_syllable) == annotations.EventData
+    assert type(parsed_syllable) == annotations.LyricData
     assert type(parsed_syllable.intervals) is np.ndarray
-    assert type(parsed_syllable.events) is list
+    assert type(parsed_syllable.lyrics) is list
 
     # Check values
     assert np.array_equal(
@@ -272,7 +296,7 @@ def test_load_syllable():
         parsed_syllable.intervals[:, 1],
         np.array([1.06, 2.65, 2.94, 3.76]),
     )
-    assert np.array_equal(parsed_syllable.events, np.array(["", "tan", "", "yang"]))
+    assert np.array_equal(parsed_syllable.lyrics, np.array(["", "tan", "", "yang"]))
 
     assert compmusic_jingju_acappella.load_syllable(None) is None
 
