@@ -9,18 +9,24 @@ from tests.test_utils import run_track_tests
 
 def test_track():
     default_trackid = "Beethoven-S3-I-ex1"
-    data_home = "tests/resources/mir_datasets/orchset"
+    data_home = os.path.normpath("tests/resources/mir_datasets/orchset")
     dataset = orchset.Dataset(data_home)
     track = dataset.track(default_trackid)
 
     expected_attributes = {
         "track_id": "Beethoven-S3-I-ex1",
-        "audio_path_mono": "tests/resources/mir_datasets/orchset/"
-        + "audio/mono/Beethoven-S3-I-ex1.wav",
-        "audio_path_stereo": "tests/resources/mir_datasets/orchset/"
-        + "audio/stereo/Beethoven-S3-I-ex1.wav",
-        "melody_path": "tests/resources/mir_datasets/orchset/"
-        + "GT/Beethoven-S3-I-ex1.mel",
+        "audio_path_mono": os.path.join(
+            os.path.normpath("tests/resources/mir_datasets/orchset/"),
+            "audio/mono/Beethoven-S3-I-ex1.wav",
+        ),
+        "audio_path_stereo": os.path.join(
+            os.path.normpath("tests/resources/mir_datasets/orchset/"),
+            "audio/stereo/Beethoven-S3-I-ex1.wav",
+        ),
+        "melody_path": os.path.join(
+            os.path.normpath("tests/resources/mir_datasets/orchset/"),
+            "GT/Beethoven-S3-I-ex1.mel",
+        ),
         "composer": "Beethoven",
         "work": "S3-I",
         "excerpt": "1",
