@@ -1,3 +1,4 @@
+import os
 import pretty_midi
 
 from mirdata import annotations
@@ -7,7 +8,7 @@ from tests.test_utils import run_track_tests, run_multitrack_tests
 
 def test_track():
     default_trackid = "Track00001-S00"
-    data_home = "tests/resources/mir_datasets/slakh"
+    data_home = os.path.normpath("tests/resources/mir_datasets/slakh")
     dataset = slakh.Dataset(data_home, version="test")
 
     track = dataset.track(default_trackid)
@@ -15,10 +16,19 @@ def test_track():
     expected_attributes = {
         "track_id": "Track00001-S00",
         "mtrack_id": "Track00001",
-        "audio_path": "tests/resources/mir_datasets/slakh/babyslakh_16k/Track00001/stems/S00.wav",
-        "midi_path": "tests/resources/mir_datasets/slakh/babyslakh_16k/Track00001/MIDI/S00.mid",
+        "audio_path": os.path.join(
+            os.path.normpath("tests/resources/mir_datasets/slakh/"),
+            "babyslakh_16k/Track00001/stems/S00.wav",
+        ),
+        "midi_path": os.path.join(
+            os.path.normpath("tests/resources/mir_datasets/slakh/"),
+            "babyslakh_16k/Track00001/MIDI/S00.mid",
+        ),
         "metadata_path": (
-            "tests/resources/mir_datasets/slakh/babyslakh_16k/Track00001/metadata.yaml"
+            os.path.join(
+                os.path.normpath("tests/resources/mir_datasets/slakh/"),
+                "babyslakh_16k/Track00001/metadata.yaml",
+            )
         ),
         "instrument": "Guitar",
         "integrated_loudness": -12.82074180245363,
@@ -68,19 +78,28 @@ def test_track():
 
 def test_track_full():
     default_trackid = "Track00001-S00"
-    data_home = "tests/resources/mir_datasets/slakh"
+    data_home = os.path.normpath("tests/resources/mir_datasets/slakh")
     dataset_full = slakh.Dataset(data_home, version="2100-redux")
     track_full = dataset_full.track(default_trackid)
 
     expected_attributes = {
         "track_id": "Track00001-S00",
         "mtrack_id": "Track00001",
-        "audio_path": "tests/resources/mir_datasets/slakh/slakh2100_flac_redux/train/Track00001/stems/S00.flac",
+        "audio_path": os.path.join(
+            os.path.normpath("tests/resources/mir_datasets/slakh/"),
+            "slakh2100_flac_redux/train/Track00001/stems/S00.flac",
+        ),
         "midi_path": (
-            "tests/resources/mir_datasets/slakh/slakh2100_flac_redux/train/Track00001/MIDI/S00.mid"
+            os.path.join(
+                os.path.normpath("tests/resources/mir_datasets/slakh/"),
+                "slakh2100_flac_redux/train/Track00001/MIDI/S00.mid",
+            )
         ),
         "metadata_path": (
-            "tests/resources/mir_datasets/slakh/slakh2100_flac_redux/train/Track00001/metadata.yaml"
+            os.path.join(
+                os.path.normpath("tests/resources/mir_datasets/slakh/"),
+                "slakh2100_flac_redux/train/Track00001/metadata.yaml",
+            )
         ),
         "instrument": "Guitar",
         "integrated_loudness": -12.82074180245363,
@@ -158,16 +177,25 @@ def test_to_jams():
 
 def test_multitrack():
     default_trackid = "Track00001"
-    data_home = "tests/resources/mir_datasets/slakh"
+    data_home = os.path.normpath("tests/resources/mir_datasets/slakh")
     dataset = slakh.Dataset(data_home, version="test")
     mtrack = dataset.multitrack(default_trackid)
 
     expected_attributes = {
         "mtrack_id": "Track00001",
-        "midi_path": "tests/resources/mir_datasets/slakh/babyslakh_16k/Track00001/all_src.mid",
-        "mix_path": "tests/resources/mir_datasets/slakh/babyslakh_16k/Track00001/mix.wav",
+        "midi_path": os.path.join(
+            os.path.normpath("tests/resources/mir_datasets/slakh/"),
+            "babyslakh_16k/Track00001/all_src.mid",
+        ),
+        "mix_path": os.path.join(
+            os.path.normpath("tests/resources/mir_datasets/slakh/"),
+            "babyslakh_16k/Track00001/mix.wav",
+        ),
         "metadata_path": (
-            "tests/resources/mir_datasets/slakh/babyslakh_16k/Track00001/metadata.yaml"
+            os.path.join(
+                os.path.normpath("tests/resources/mir_datasets/slakh/"),
+                "babyslakh_16k/Track00001/metadata.yaml",
+            )
         ),
         "data_split": None,
         "track_ids": [
