@@ -1,3 +1,4 @@
+from logging import fatal
 import os
 from pathlib import Path
 import shutil
@@ -42,63 +43,63 @@ def test_downloader(mocker, mock_path):
     )
 
     zip_remote = download_utils.RemoteFileMetadata(
-        filename="remote.zip", url="a", checksum="1234"
+        filename="remote.zip", url="a", checksum=("1234")
     )
     tar_remote = download_utils.RemoteFileMetadata(
-        filename="remote.tar.gz", url="a", checksum="1234"
+        filename="remote.tar.gz", url="a", checksum=("1234")
     )
 
     file_remote = download_utils.RemoteFileMetadata(
-        filename="remote.txt", url="a", checksum="1234"
+        filename="remote.txt", url="a", checksum=("1234")
     )
     index = core.Index("asdf.json")
 
     # Zip only
     download_utils.downloader("a", index=index, remotes={"b": zip_remote})
-    mock_zip.assert_called_once_with(zip_remote, "a", False, False)
+    mock_zip.assert_called_once_with(zip_remote, "a", False, False, False)
     mocker.resetall()
 
     # tar only
     download_utils.downloader("a", index=index, remotes={"b": tar_remote})
-    mock_tar.assert_called_once_with(tar_remote, "a", False, False)
+    mock_tar.assert_called_once_with(tar_remote, "a", False, False, False)
     mocker.resetall()
 
     # file only
     download_utils.downloader("a", index=index, remotes={"b": file_remote})
-    mock_download_from_remote.assert_called_once_with(file_remote, "a", False)
+    mock_download_from_remote.assert_called_once_with(file_remote, "a", False, False)
     mocker.resetall()
 
     # zip and tar
     download_utils.downloader(
         "a", index=index, remotes={"b": zip_remote, "c": tar_remote}
     )
-    mock_zip.assert_called_once_with(zip_remote, "a", False, False)
-    mock_tar.assert_called_once_with(tar_remote, "a", False, False)
+    mock_zip.assert_called_once_with(zip_remote, "a", False, False, False)
+    mock_tar.assert_called_once_with(tar_remote, "a", False, False, False)
     mocker.resetall()
 
     # zip and file
     download_utils.downloader(
         "a", index=index, remotes={"b": zip_remote, "c": file_remote}
     )
-    mock_zip.assert_called_once_with(zip_remote, "a", False, False)
-    mock_download_from_remote.assert_called_once_with(file_remote, "a", False)
+    mock_zip.assert_called_once_with(zip_remote, "a", False, False, False)
+    mock_download_from_remote.assert_called_once_with(file_remote, "a", False, False)
     mocker.resetall()
 
     # tar and file
     download_utils.downloader(
         "a", index=index, remotes={"b": tar_remote, "c": file_remote}
     )
-    mock_tar.assert_called_once_with(tar_remote, "a", False, False)
-    mock_download_from_remote.assert_called_once_with(file_remote, "a", False)
+    mock_tar.assert_called_once_with(tar_remote, "a", False, False, False)
+    mock_download_from_remote.assert_called_once_with(file_remote, "a", False, False)
     mocker.resetall()
 
     # zip and tar and file
     download_utils.downloader(
         "a", index=index, remotes={"b": zip_remote, "c": tar_remote, "d": file_remote}
     )
-    mock_zip.assert_called_once_with(zip_remote, "a", False, False)
-    mock_download_from_remote.assert_called_once_with(file_remote, "a", False)
-    mock_tar.assert_called_once_with(tar_remote, "a", False, False)
+    mock_zip.assert_called_once_with(zip_remote, "a", False, False, False)
+    mock_download_from_remote.assert_called_once_with(file_remote, "a", False, False)
+    mock_tar.assert_called_once_with(tar_remote, "a", False, False, False)
     mocker.resetall()
 
     # test partial download
@@ -108,8 +109,8 @@ def test_downloader(mocker, mock_path):
         remotes={"b": zip_remote, "c": tar_remote, "d": file_remote},
         partial_download=["b", "d"],
     )
-    mock_zip.assert_called_once_with(zip_remote, "a", False, False)
-    mock_download_from_remote.assert_called_once_with(file_remote, "a", False)
+    mock_zip.assert_called_once_with(zip_remote, "a", False, False, False)
+    mock_download_from_remote.assert_called_once_with(file_remote, "a", False, False)
     mocker.resetall()
 
     # test bad type partial download
@@ -160,22 +161,17 @@ def test_download_index_cases(mocker, mock_path):
     )
 
     zip_remote = download_utils.RemoteFileMetadata(
-        filename="remote.zip", url="a", checksum="1234"
+        filename="remote.zip", url="a", checksum=("1234")
     )
     file_remote = download_utils.RemoteFileMetadata(
-        filename="remote.txt", url="a", checksum="1234"
+        filename="remote.txt", url="a", checksum=("1234")
     )
     index = core.Index("asdf.json")
     index_partial = core.Index("asdf.json", partial_download=["b"])
     remote_index = core.Index("asdf.json", url="b", checksum="4567")
 
     # no remotes, no remote index
-    download_utils.downloader(
-        "a",
-        index=index,
-        remotes=None,
-        partial_download=None,
-    )
+    download_utils.downloader("a", index=index, remotes=None, partial_download=None)
     mock_zip.assert_not_called()
     mock_download_from_remote.assert_not_called()
     mocker.resetall()
@@ -187,7 +183,7 @@ def test_download_index_cases(mocker, mock_path):
         remotes={"b": zip_remote, "d": file_remote},
         partial_download=None,
     )
-    mock_zip.assert_called_once_with(zip_remote, "a", False, False)
+    mock_zip.assert_called_once_with(zip_remote, "a", False, False, False)
     mock_download_from_remote.assert_not_called()
     mocker.resetall()
 
@@ -199,29 +195,27 @@ def test_download_index_cases(mocker, mock_path):
         partial_download=["d"],
     )
     mock_zip.assert_not_called()
-    mock_download_from_remote.assert_called_once_with(file_remote, "a", False)
+    mock_download_from_remote.assert_called_once_with(file_remote, "a", False, False)
     mocker.resetall()
 
     # no remotes, remote index
     download_utils.downloader(
-        "a",
-        index=remote_index,
-        remotes=None,
-        partial_download=None,
+        "a", index=remote_index, remotes=None, partial_download=None
     )
     mock_zip.assert_not_called()
-    mock_download_from_remote.assert_called_once_with(remote_index.remote, "a", False)
+    mock_download_from_remote.assert_called_once_with(
+        remote_index.remote, "a", False, False
+    )
     mocker.resetall()
 
     # remotes, remote index
     download_utils.downloader(
-        "a",
-        index=remote_index,
-        remotes={"b": zip_remote},
-        partial_download=None,
+        "a", index=remote_index, remotes={"b": zip_remote}, partial_download=None
+    )
+    mock_zip.assert_called_once_with(zip_remote, "a", False, False, False)
+    mock_download_from_remote.assert_called_once_with(
+        remote_index.remote, "a", False, False
     )
-    mock_zip.assert_called_once_with(zip_remote, "a", False, False)
-    mock_download_from_remote.assert_called_once_with(remote_index.remote, "a", False)
     mocker.resetall()
 
 
@@ -237,7 +231,7 @@ def test_downloader_with_server_file(httpserver):
     TEST_REMOTE = download_utils.RemoteFileMetadata(
         filename="remote.wav",
         url=httpserver.url,
-        checksum="3f77d0d69dc41b3696f074ad6bf2852f",
+        checksum=("3f77d0d69dc41b3696f074ad6bf2852f"),
     )
 
     save_dir = "tests/resources/tmp_download_test"
@@ -263,6 +257,57 @@ def test_downloader_with_server_file(httpserver):
 
     _clean(save_dir)
 
+    # test with wrong checksum: raises error
+    TEST_REMOTE = download_utils.RemoteFileMetadata(
+        filename="remote.wav", url=httpserver.url, checksum=("wrongchecksum")
+    )
+
+    with pytest.raises(OSError):
+        _clean(save_dir)
+        download_utils.downloader(save_dir, index=index, remotes={"b": TEST_REMOTE})
+
+    with pytest.raises(OSError):
+        _clean(save_dir)
+        download_utils.downloader(
+            save_dir, index=index, remotes={"b": TEST_REMOTE}, cleanup=True
+        )
+
+    with pytest.raises(OSError):
+        _clean(save_dir)
+        download_utils.downloader(
+            save_dir, index=index, remotes={"b": TEST_REMOTE}, force_overwrite=True
+        )
+
+    # test with wrong checksum: ignore error
+    with pytest.warns(UserWarning):
+        _clean(save_dir)
+        download_utils.downloader(
+            save_dir,
+            index=index,
+            remotes={"b": TEST_REMOTE},
+            allow_invalid_checksum=True,
+        )
+
+    with pytest.warns(UserWarning):
+        _clean(save_dir)
+        download_utils.downloader(
+            save_dir,
+            index=index,
+            remotes={"b": TEST_REMOTE},
+            cleanup=True,
+            allow_invalid_checksum=True,
+        )
+
+    with pytest.warns(UserWarning):
+        _clean(save_dir)
+        download_utils.downloader(
+            save_dir,
+            index=index,
+            remotes={"b": TEST_REMOTE},
+            force_overwrite=True,
+            allow_invalid_checksum=True,
+        )
+
 
 def test_downloader_with_server_zip(httpserver):
     index = core.Index("asdf.json")
@@ -271,7 +316,7 @@ def test_downloader_with_server_zip(httpserver):
     TEST_REMOTE = download_utils.RemoteFileMetadata(
         filename="remote.zip",
         url=httpserver.url,
-        checksum="7a31ccfa28bfa3fb112d16c96e9d9a89",
+        checksum=("7a31ccfa28bfa3fb112d16c96e9d9a89"),
     )
 
     save_dir = "tests/resources/_tmp_test_download_utils"
@@ -314,7 +359,7 @@ def test_downloader_with_server_tar(httpserver):
     TEST_REMOTE = download_utils.RemoteFileMetadata(
         filename="remote.tar.gz",
         url=httpserver.url,
-        checksum="9042f5eebdcd0b94aa7a3c9bf12dc51d",
+        checksum=("9042f5eebdcd0b94aa7a3c9bf12dc51d"),
     )
 
     save_dir = "tests/resources/_tmp_test_download_utils"
@@ -347,10 +392,12 @@ def test_download_from_remote(httpserver, tmpdir):
     TEST_REMOTE = download_utils.RemoteFileMetadata(
         filename="remote.wav",
         url=httpserver.url,
-        checksum="3f77d0d69dc41b3696f074ad6bf2852f",
+        checksum=("3f77d0d69dc41b3696f074ad6bf2852f"),
     )
 
-    download_path = download_utils.download_from_remote(TEST_REMOTE, str(tmpdir), False)
+    download_path = download_utils.download_from_remote(
+        TEST_REMOTE, str(tmpdir), False, False
+    )
 
 
 def test_download_from_remote_destdir(httpserver, tmpdir):
@@ -359,11 +406,13 @@ def test_download_from_remote_destdir(httpserver, tmpdir):
     TEST_REMOTE = download_utils.RemoteFileMetadata(
         filename="remote.wav",
         url=httpserver.url,
-        checksum="3f77d0d69dc41b3696f074ad6bf2852f",
+        checksum=("3f77d0d69dc41b3696f074ad6bf2852f"),
         destination_dir="subfolder",
     )
 
-    download_path = download_utils.download_from_remote(TEST_REMOTE, str(tmpdir), False)
+    download_path = download_utils.download_from_remote(
+        TEST_REMOTE, str(tmpdir), False, False
+    )
     expected_download_path = os.path.join(str(tmpdir), "subfolder", "remote.wav")
     assert expected_download_path == download_path
 
@@ -372,26 +421,11 @@ def test_download_from_remote_raises_IOError(httpserver, tmpdir):
     httpserver.serve_content("File not found!", 404)
 
     TEST_REMOTE = download_utils.RemoteFileMetadata(
-        filename="remote.wav",
-        url=httpserver.url,
-        checksum="1234",
+        filename="remote.wav", url=httpserver.url, checksum=("1234")
     )
 
     with pytest.raises(IOError):
-        download_utils.download_from_remote(TEST_REMOTE, str(tmpdir), False)
-
-
-def test_download_from_remote_raises_NotImplementedError(httpserver, tmpdir):
-    httpserver.serve_content("File not found!", 404)
-
-    TEST_REMOTE = download_utils.RemoteFileMetadata(
-        filename="remote.wav",
-        url=httpserver.url,
-        checksum="1234",
-    )
-
-    with pytest.raises(NotImplementedError):
-        download_utils.download_from_remote(TEST_REMOTE, "gs://asdf/asdf/asdf", False)
+        download_utils.download_from_remote(TEST_REMOTE, str(tmpdir), False, False)
 
 
 def test_unzip():
@@ -410,18 +444,40 @@ def test_untar():
 
 def test_download_zip_file(mocker, mock_download_from_remote, mock_unzip):
     mock_download_from_remote.return_value = "foo"
-    download_utils.download_zip_file("a", "b", False, False)
+    download_utils.download_zip_file("a", "b", False, False, False)
 
-    mock_download_from_remote.assert_called_once_with("a", "b", False)
+    mock_download_from_remote.assert_called_once_with("a", "b", False, False)
+    mock_unzip.assert_called_once_with("foo", cleanup=False)
+    _clean("a")
+
+
+def test_download_zip_file_ignorechecksum(
+    mocker, mock_download_from_remote, mock_unzip
+):
+    mock_download_from_remote.return_value = "foo"
+    download_utils.download_zip_file("a", "b", False, False, True)
+
+    mock_download_from_remote.assert_called_once_with("a", "b", False, True)
     mock_unzip.assert_called_once_with("foo", cleanup=False)
     _clean("a")
 
 
 def test_download_tar_file(mocker, mock_download_from_remote, mock_untar):
     mock_download_from_remote.return_value = "foo"
-    download_utils.download_tar_file("a", "b", False, False)
+    download_utils.download_tar_file("a", "b", False, False, False)
 
-    mock_download_from_remote.assert_called_once_with("a", "b", False)
+    mock_download_from_remote.assert_called_once_with("a", "b", False, False)
+    mock_untar.assert_called_once_with("foo", cleanup=False)
+    _clean("a")
+
+
+def test_download_tar_file_ignorechecksum(
+    mocker, mock_download_from_remote, mock_untar
+):
+    mock_download_from_remote.return_value = "foo"
+    download_utils.download_tar_file("a", "b", False, False, True)
+
+    mock_download_from_remote.assert_called_once_with("a", "b", False, True)
     mock_untar.assert_called_once_with("foo", cleanup=False)
     _clean("a")
 
