@@ -79,11 +79,18 @@ def test_beats():
             None,
         )
     ]
+    beat_data_8 = [
+        (
+            annotations.BeatData(np.array([0.2, 0.3]), "s", None, "bar_index"),
+            None,
+        )
+    ]
 
     jam_1 = jams_utils.jams_converter(beat_data=beat_data_1)
     jam_2 = jams_utils.jams_converter(beat_data=beat_data_2)
     jam_3 = jams_utils.jams_converter(beat_data=beat_data_3)
     jam_6 = jams_utils.jams_converter(beat_data=beat_data_6)
+    jam_8 = jams_utils.jams_converter(beat_data=beat_data_8)
 
     time, duration, value, confidence = get_jam_data(jam_1, "beat", 0)
     assert time == [0.2, 0.3]
@@ -111,6 +118,12 @@ def test_beats():
     assert value == []
     assert confidence == []
 
+    time, duration, value, confidence = get_jam_data(jam_8, "beat", 0)
+    assert time == [0.2, 0.3]
+    assert duration == [0.0, 0.0]
+    assert value == [None, None]
+    assert confidence == [None, None]
+
     assert type(jam_1) == jams.JAMS
 
     with pytest.raises(TypeError):
