@@ -14,11 +14,17 @@ DATASETS = mirdata.DATASETS
 CUSTOM_TEST_TRACKS = {
     "beatles": "0111",
     "cante100": "008",
+    "compmusic_carnatic_rhythm": "10003",
+    "compmusic_hindustani_rhythm": "20001",
+    "compmusic_indian_tonic": "0a6ebaa4-87cc-452d-a7af-a2006e96f16a_0-180",
     "compmusic_jingju_acappella": "lseh-Tan_Yang_jia-Hong_yang_dong-qm",
     "compmusic_otmm_makam": "cafcdeaf-e966-4ff0-84fb-f660d2b68365",
+    "compmusic_raga": "Aruna_Sairam.Valli_Kanavan",
+    "four_way_tabla": "AHK_solo-tintal-1",
     "giantsteps_key": "3",
     "dali": "4b196e6c99574dd49ad00d56e132712b",
     "da_tacos": "coveranalysis#W_163992#P_547131",
+    "filosax": "multitrack_02_sax_1",
     "freesound_one_shot_percussive_sounds": "183",
     "giantsteps_tempo": "113",
     "gtzan_genre": "country.00000",
@@ -30,9 +36,10 @@ CUSTOM_TEST_TRACKS = {
     "rwc_classical": "RM-C003",
     "rwc_jazz": "RM-J004",
     "rwc_popular": "RM-P001",
+    "openmic2018": "000046_3840",
     "salami": "2",
     "saraga_carnatic": "116_Bhuvini_Dasudane",
-    "saraga_hindustani": "59_Bairagi",
+    "saraga_hindustani": "50_Irani_Bhairavi_Thumri",
     "tinysol": "Fl-ord-C4-mf-N-T14d",
     "dagstuhl_choirset": "DCS_LI_QuartetB_Take04_B2",
     "tonas": "01-D_AMairena",
@@ -252,7 +259,9 @@ def test_track():
     for dataset_name in DATASETS:
 
         dataset = mirdata.initialize(
-            dataset_name, os.path.join(TEST_DATA_HOME, dataset_name), version="test"
+            dataset_name,
+            os.path.normpath(os.path.join(TEST_DATA_HOME, dataset_name)),
+            version="test",
         )
 
         # if the dataset doesn't have a track object, make sure it raises a value error
